@@ -14,7 +14,11 @@ describe 'neutron' do
     it_behaves_like 'a neutron base installation'
 
     context 'with rabbitmq heartbeat configured' do
-      before { params.merge!( :rabbit_heartbeat_timeout_threshold => '60', :rabbit_heartbeat_rate => '10' ) }
+      before { params.merge!( 
+        :rabbit_heartbeat_timeout_threshold => '60',
+        :rabbit_heartbeat_rate => '10',
+        :rabbit_heartbeat_in_pthread => true,
+      ) }
       it_behaves_like 'rabbit with heartbeat configured'
     end
 
@@ -76,6 +80,7 @@ describe 'neutron' do
     it 'configures rabbit' do
       should contain_neutron_config('oslo_messaging_rabbit/heartbeat_timeout_threshold').with_value('<SERVICE DEFAULT>')
       should contain_neutron_config('oslo_messaging_rabbit/heartbeat_rate').with_value('<SERVICE DEFAULT>')
+      should contain_neutron_config('oslo_messaging_rabbit/heartbeat_in_pthread').with_value('<SERVICE DEFAULT>')
       should contain_neutron_config('oslo_messaging_rabbit/kombu_reconnect_delay').with_value( '<SERVICE DEFAULT>' )
       should contain_neutron_config('oslo_messaging_rabbit/kombu_missing_consumer_retry_timeout').with_value( '<SERVICE DEFAULT>' )
       should contain_neutron_config('oslo_messaging_rabbit/kombu_failover_strategy').with_value( '<SERVICE DEFAULT>' )
@@ -100,6 +105,7 @@ describe 'neutron' do
       should contain_neutron_config('DEFAULT/control_exchange').with_value('neutron')
       should contain_neutron_config('DEFAULT/state_path').with_value('<SERVICE DEFAULT>')
       should contain_neutron_config('oslo_concurrency/lock_path').with_value('$state_path/lock')
+      should contain_neutron_config('DEFAULT/executor_thread_pool_size').with_value('<SERVICE DEFAULT>')
       should contain_neutron_config('DEFAULT/transport_url').with_value('<SERVICE DEFAULT>')
       should contain_neutron_config('DEFAULT/rpc_response_timeout').with_value('<SERVICE DEFAULT>')
       should contain_neutron_config('DEFAULT/vlan_transparent').with_value('<SERVICE DEFAULT>')
@@ -113,6 +119,7 @@ describe 'neutron' do
     it 'in neutron.conf' do
       should contain_neutron_config('oslo_messaging_rabbit/heartbeat_timeout_threshold').with_value('60')
       should contain_neutron_config('oslo_messaging_rabbit/heartbeat_rate').with_value('10')
+      should contain_neutron_config('oslo_messaging_rabbit/heartbeat_in_pthread').with_value(true)
     end
   end
 
@@ -402,7 +409,6 @@ describe 'neutron' do
       it { should contain_neutron_config('oslo_messaging_amqp/ssl_cert_file').with_value('<SERVICE DEFAULT>') }
       it { should contain_neutron_config('oslo_messaging_amqp/ssl_key_file').with_value('<SERVICE DEFAULT>') }
       it { should contain_neutron_config('oslo_messaging_amqp/ssl_key_password').with_value('<SERVICE DEFAULT>') }
-      it { should contain_neutron_config('oslo_messaging_amqp/allow_insecure_clients').with_value('<SERVICE DEFAULT>') }
       it { should contain_neutron_config('oslo_messaging_amqp/sasl_mechanisms').with_value('<SERVICE DEFAULT>') }
       it { should contain_neutron_config('oslo_messaging_amqp/sasl_config_dir').with_value('<SERVICE DEFAULT>') }
       it { should contain_neutron_config('oslo_messaging_amqp/sasl_config_name').with_value('<SERVICE DEFAULT>') }
@@ -430,7 +436,6 @@ describe 'neutron' do
       it { should contain_neutron_config('oslo_messaging_amqp/ssl_ca_file').with_value('/path/to/ca.cert') }
       it { should contain_neutron_config('oslo_messaging_amqp/ssl_cert_file').with_value('/path/to/certfile') }
       it { should contain_neutron_config('oslo_messaging_amqp/ssl_key_file').with_value('/path/to/key') }
-      it { should contain_neutron_config('oslo_messaging_amqp/allow_insecure_clients').with_value('<SERVICE DEFAULT>') }
       it { should contain_neutron_config('oslo_messaging_amqp/sasl_mechanisms').with_value('<SERVICE DEFAULT>') }
       it { should contain_neutron_config('oslo_messaging_amqp/sasl_config_dir').with_value('<SERVICE DEFAULT>') }
       it { should contain_neutron_config('oslo_messaging_amqp/sasl_config_name').with_value('<SERVICE DEFAULT>') }
