@@ -41,7 +41,8 @@ describe 'neutron::quota' do
           :quota_security_group_rule => 200,
           :quota_network_gateway     => 5,
           :quota_packet_filter       => 100,
-          :quota_vip                 => 10
+          :quota_vip                 => 10,
+          :quota_rbac_policy         => 10
         })
       end
 
